==> deepin-screenshot_4.0.11.orig.tar.gz: deepin-screenshot-4.0.11/translations/deepin-screenshot_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>select-area</source>
        <translation>seleccione el área</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="951"/>
        <location filename="../mainwindow.cpp" line="953"/>
        <location filename="../mainwindow.cpp" line="1209"/>
        <location filename="../mainwindow.cpp" line="1212"/>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1228"/>
        <location filename="../mainwindow.cpp" line="1268"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <location filename="../mainwindow.cpp" line="1303"/>
        <location filename="../mainwindow.cpp" line="1306"/>
        <source>DeepinScreenshot</source>
        <translation>DeepinScreenshot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="1321"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="1341"/>
        <source>Picture has been saved to %1</source>
        <translation>La imagen se ha guardado en % 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Picture has been saved to clipboard</source>
        <translation>La imagen ha sido copiada al portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="15"/>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="23"/>
        <source>Ellipse</source>
        <translation>Elípse</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="31"/>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="39"/>
        <source>Pencil</source>
        <translation>Làpiz</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="47"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="55"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="71"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="74"/>
        <source>Save to desktop</source>
        <translation>Guardar en el escritorio</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="75"/>
        <source>Autosave</source>
        <translation>Atoguardado</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="76"/>
        <source>Save to specified folder</source>
        <translation>Guardar en carpeta especificada</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="77"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="78"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Autoguardar y copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="59"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>La captura de pantalla comenzará después de % 1 segundos</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="10"/>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Capturar pantalla</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="11"/>
        <location filename="../utils/shortcut.cpp" line="22"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="12"/>
        <source>Painting</source>
        <translation>Pintar</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="13"/>
        <source>Size Adjustment</source>
        <translation>Ajuste de tamaño</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="16"/>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="17"/>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="18"/>
        <source>Delay screenshot</source>
        <translation>Retrasar captura</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="19"/>
        <source>Undo</source>
        <translation>Deshacer </translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="20"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="23"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="26"/>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="27"/>
        <source>Ellipse</source>
        <translation>Elípse</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="28"/>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Pencil</source>
        <translation> Lápiz</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="34"/>
        <source>Increase height up</source>
        <translation>Incrementar altura superior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Increase height down</source>
        <translation>Disminuir altura inferior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Increase width left</source>
        <translation>Incrementar anchura izquierda</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Increase width right</source>
        <translation>Incrementar anchura derecha</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Decrease height up</source>
        <translation>Reducir altura superior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Decrease height down</source>
        <translation>Reducir altura inferior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="40"/>
        <source>Decrease width left</source>
        <translation>Reducir anchura izquiera</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Decrease width right</source>
        <translation>Reducir anchura derecha</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="377"/>
        <source>Save to desktop</source>
        <translation>Guardar en el escritorio</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="383"/>
        <source>Autosave</source>
        <translation>Atoguardado</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="389"/>
        <source>Save to specified folder</source>
        <translation>Guardar en carpeta especificada</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="395"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="400"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Autoguardar y copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="405"/>
        <source>Low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="419"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
</context>
</TS>

==> deepin-screenshot_4.1.8.orig.tar.gz: deepin-screenshot-4.1.8/translations/deepin-screenshot_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_419" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>select-area</source>
        <translation>seleccione el área</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="986"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1246"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1262"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1302"/>
        <location filename="../mainwindow.cpp" line="1305"/>
        <location filename="../mainwindow.cpp" line="1337"/>
        <location filename="../mainwindow.cpp" line="1340"/>
        <source>DeepinScreenshot</source>
        <translation>DeepinScreenshot</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1366"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <location filename="../mainwindow.cpp" line="1386"/>
        <source>Picture has been saved to %1</source>
        <translation>La imagen se ha guardado en % 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1360"/>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Picture has been saved to clipboard</source>
        <translation>La imagen ha sido copiada al portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="48"/>
        <source>Ellipse</source>
        <translation>Elípse</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="56"/>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="64"/>
        <source>Pencil</source>
        <translation>Làpiz</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="72"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="96"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Save to desktop</source>
        <translation>Guardar en el escritorio</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="100"/>
        <source>Autosave</source>
        <translation>Atoguardado</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="101"/>
        <source>Save to specified folder</source>
        <translation>Guardar en carpeta especificada</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="102"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="103"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Autoguardar y copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="124"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="78"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>La captura de pantalla comenzará después de % 1 segundos</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Start/Screenshot</source>
        <translation>Iniciar/Capturar pantalla</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Painting</source>
        <translation>Pintar</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="32"/>
        <source>Size Adjustment</source>
        <translation>Ajuste de tamaño</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Quick start</source>
        <translation>Inicio rápido</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Full screenshot</source>
        <translation>Captura de pantalla completa</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Delay screenshot</source>
        <translation>Retrasar captura</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Undo</source>
        <translation>Deshacer </translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="42"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="45"/>
        <source>Rectangle</source>
        <translation>Rectángulo</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="46"/>
        <source>Ellipse</source>
        <translation>Elípse</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="47"/>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="48"/>
        <source>Pencil</source>
        <translation> Lápiz</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="49"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="50"/>
        <source>Color</source>
        <translation>Color</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="53"/>
        <source>Increase height up</source>
        <translation>Incrementar altura superior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="54"/>
        <source>Increase height down</source>
        <translation>Disminuir altura inferior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="55"/>
        <source>Increase width left</source>
        <translation>Incrementar anchura izquierda</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="56"/>
        <source>Increase width right</source>
        <translation>Incrementar anchura derecha</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="57"/>
        <source>Decrease height up</source>
        <translation>Reducir altura superior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="58"/>
        <source>Decrease height down</source>
        <translation>Reducir altura inferior</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="59"/>
        <source>Decrease width left</source>
        <translation>Reducir anchura izquiera</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="60"/>
        <source>Decrease width right</source>
        <translation>Reducir anchura derecha</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="397"/>
        <source>Save to desktop</source>
        <translation>Guardar en el escritorio</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="403"/>
        <source>Autosave</source>
        <translation>Atoguardado</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="409"/>
        <source>Save to specified folder</source>
        <translation>Guardar en carpeta especificada</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="415"/>
        <source>Copy to clipboard</source>
        <translation>Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="420"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Autoguardar y copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="425"/>
        <source>Low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="439"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
</context>
</TS>
